type Func = (...args: any[]) => any;
type Modifier = (fn: (...args: any[]) => void) => (...args: any[]) => void;
interface Callable {
    <F extends Func>(fn: F, ...modifiers: Modifier[]): (...args: Parameters<F>) => ReturnType<F>;
    /**
     * For cases where you want to use the same `callable` with the `once` event modifier for each iteration of an `{#each}` loop\
     * The returned wrapper function takes in a unique key of type `string | number`, ideally the current index or unique key of your loop
     *
     * ```svelte
     * <script>
     *     const buttons = ['1', '2', '3'];
     *
     *     const handler = callable.forEach(name => {
     *         console.log(`clicked button number ${name}!`);
     *     }, once);
     * </script>
     *
     * {#each buttons as buttonName, index}
     *     <button onclick={() => handler(index)(buttonName)}>
     *         <span>click me!</span>
     *     </button>
     * {/each}
     * ```
     *
     * @param fn Callback function
     * @param modifiers Event modifiers
     * @returns A function that wraps the callback function
     */
    forEach<F extends Func>(fn: F, ...modifiers: Modifier[]): (key: string | number) => (...args: Parameters<F>) => ReturnType<F>;
}
export declare function trusted<F extends Func>(fn: F): (...args: Parameters<F>) => any;
export declare function self<F extends Func>(fn: F): (...args: Parameters<F>) => any;
export declare function stopPropagation<F extends Func>(fn: F): (...args: Parameters<F>) => any;
export declare function once<F extends Func>(fn: F): (...args: Parameters<F>) => any;
export declare function stopImmediatePropagation<F extends Func>(fn: F): (...args: Parameters<F>) => any;
export declare function preventDefault<F extends Func>(fn: F): (...args: Parameters<F>) => any;
/**
 * Creates a callable function with event modifiers
 *
 * ```svelte
 * <script>
 *     const onclick = callable(() => {
 *         console.log('clicked!');
 *     }, preventDefault);
 * </script>
 *
 * <a href="/meow" {onclick}>
 *     <span>i won't redirect you!</span>
 * </a>
 * ```
 *
 * @param fn Callback function
 * @param modifiers Event modifiers
 * @returns The callback function
 */
declare const callable: Callable;
export default callable;
